@@ -10,20 +10,21 @@
 namespace SebastianBergmann\Complexity;
 
 use function file_get_contents;
+use PhpParser\Lexer;
 use PhpParser\NodeTraverser;
+use PhpParser\Parser;
 use PhpParser\ParserFactory;
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
-/**
- * @covers \SebastianBergmann\Complexity\CyclomaticComplexityCalculatingVisitor
- *
- * @small
- */
+#[CoversClass(CyclomaticComplexityCalculatingVisitor::class)]
+#[Small]
 final class CyclomaticComplexityCalculatingVisitorTest extends TestCase
 {
     public function testCalculatesCyclomaticComplexityForAbstractSyntaxTree(): void
     {
-        $nodes = (new ParserFactory)->createForHostVersion()->parse(
+        $nodes = $this->parser()->parse(
             file_get_contents(__DIR__ . '/../_fixture/example_function.php')
         );
 
@@ -38,4 +39,9 @@ final class CyclomaticComplexityCalculatingVisitorTest extends TestCase
 
         $this->assertSame(14, $visitor->cyclomaticComplexity());
     }
+
+    private function parser(): Parser
+    {
+        return (new ParserFactory)->create(ParserFactory::PREFER_PHP7, new Lexer);
+    }
 }
